# eric7.EricXML.ProjectReader

Module implementing a class for reading an XML project file.

### Global Attributes

None

### Classes

ProjectReader | Class for reading an XML project file.

### Functions

None

## ProjectReader

Class for reading an XML project file.

### Derived from

XMLStreamReaderBase

### Class Attributes

supportedVersions

### Class Methods

None

### Methods

ProjectReader | Constructor
__readBasicDataField | Private method to read a list of files.
__readFiles | Private method to read a list of files.
__readFiletypeAssociations | Private method to read the file type associations.
__readLexerAssociations | Private method to read the lexer associations.
__readVcs | Private method to read the VCS info.
readXML | Public method to read and parse the XML document.

### Static Methods

None

#### ProjectReader (Constructor)

ProjectReader(device, project)

Constructor

device
  reference to the I/O device to read from (QIODevice)
project
  Reference to the project object to store the information into.

#### ProjectReader.__readBasicDataField

__readBasicDataField(tag, dataTag, dataKey)

Private method to read a list of files.

tag
  name of the list tag (string)
dataTag
  name of the data tag (string)
dataKey
  key of the project data element (string)

#### ProjectReader.__readFiles

__readFiles(tag, listTag, dataKey)

Private method to read a list of files.

tag
  name of the list tag (string)
listTag
  name of the list element tag (string)
dataKey
  key of the project data element (string)

#### ProjectReader.__readFiletypeAssociations

__readFiletypeAssociations()

Private method to read the file type associations.

#### ProjectReader.__readLexerAssociations

__readLexerAssociations()

Private method to read the lexer associations.

#### ProjectReader.__readVcs

__readVcs()

Private method to read the VCS info.

#### ProjectReader.readXML

readXML()

Public method to read and parse the XML document.

Up